#!/bin/sh
SLACKPKG="/etc/slackpkg"

if ! [ -e $SLACKPKG/mirrors ]; then
	mv $SLACKPKG/mirrors.new $SLACKPKG/mirrors
fi

if ! [ -e $SLACKPKG/slackpkg.conf ]; then
	mv $SLACKPKG/slackpkg.conf.new $SLACKPKG/slackpkg.conf
fi

if ! [ -e $SLACKPKG/blacklist ]; then
	mv $SLACKPKG/blacklist.new $SLACKPKG/blacklist
fi
